@@ -3,6 +3,10 @@
 # Updated:
 #  June 12, 2019. Fixed a test case due to wrong code before.
 #  October 29, 2019 Added a test case for 2X2 tables
+#  Jan 2020. Some basic tests are added for the differential 
+#    simulator function.
+#  March 18, 2020. Improved readability of code.
+#  March 19, 2020. More tests are added for the simulator function.
 
 library(testthat)
 library(DiffXTables)
@@ -151,10 +155,11 @@ test_that("Testing sharma.song.test", {
 
 })
 
+context("Testing cp.chisq.test()")
+
 # Testing comparative chi square test
 test_that("Testing comparative chi-squared test", {
   
-  
   # 2X2 matrix test
   x <- list(
     matrix(c(4,0,
@@ -232,6 +237,7 @@ test_that("Testing comparative chi-squared test", {
 
 })
 
+context("Testing heterogeneity.test()")
 # Testing heterogeneity test
 test_that("Testing heterogeneity test", {
   
@@ -293,8 +299,6 @@ test_that("Testing heterogeneity test", {
   expect_equivalent(signif(h$statistic, 8), 36)
   expect_equivalent(h$parameter, 4)
 
-
-
   x <- matrix(c(4,0,4,
                 0,4,0,
                 1,0,1), nrow=3)
@@ -307,8 +311,80 @@ test_that("Testing heterogeneity test", {
   expect_equivalent(signif(h$p.value, 8), 0.0001144345 )
   expect_equivalent(signif(h$statistic, 8), 31.5)
   expect_equivalent(h$parameter, 8)
+  
+})
 
+context("Testing simulate_diff_tables()")
 
+# Testing simulateDiffXTables 
+test_that("Testing simulate_diff_tables method", {
+  
+  # First-order differential 3 x 4 tables for K = 3 conditions
+  x <- simulate_diff_tables(3, 3, 4, 100, 50, type = "first-order")
+  expect_equivalent(length(x$probability.tables), 3)
+  expect_equivalent(length(x$contingency.tables), 3)
+  
+  for(i in seq_along(x$contingency.tables))
+  {
+    expect_equivalent(sum(x$contingency.tables[[i]]), 100)
+    expect_equivalent(sum(x$probability.tables[[i]]), 1)
+    
+    if(i > 1) {
+      expect_equivalent(
+        sum(x$contingency.tables[[i]] != x$contingency.tables[[i-1]]) > 0,
+        TRUE
+      )
+      expect_equivalent(
+        sum(x$probability.tables[[i]] != x$probability.tables[[i-1]]) > 0,
+        TRUE
+      )
+    }
+  }
+  
+  # 3X5 second-order tables for K = 4 conditions
+  x <- simulate_diff_tables(4, 3, 5, 140, 70, type = "second-order")
+  expect_equivalent(length(x$contingency.tables), 4)
+  expect_equivalent(length(x$probability.tables), 4)
+  
+  for(i in seq_along(x$contingency.tables))
+  {
+    expect_equivalent(sum(x$contingency.tables[[i]]), 140)
+    expect_equivalent(sum(x$probability.tables[[i]]), 1)
+    
+    if(i > 1) {
+      expect_equivalent(
+        sum(x$contingency.tables[[i]] != x$contingency.tables[[i-1]]) > 0,
+        TRUE
+      )
+      expect_equivalent(
+        sum(x$probability.tables[[i]] != x$probability.tables[[i-1]]) > 0,
+        TRUE
+      )
+    }
+  }
+  
+  # 4X4 second-order tables for K = 2 conditions
+  x <- simulate_diff_tables(2, 4, 4, 140, 80, type = "full-order")
+  expect_equivalent(length(x$contingency.tables), 2)
+  expect_equivalent(length(x$probability.tables), 2)
+  
+  for(i in seq_along(x$contingency.tables))
+  {
+    expect_equivalent(sum(x$contingency.tables[[i]]), 140)
+    expect_equivalent(sum(x$probability.tables[[i]]), 1)
+    
+    if(i > 1) {
+      expect_equivalent(
+        sum(x$contingency.tables[[i]] != x$contingency.tables[[i-1]]) > 0,
+        TRUE
+      )
+      expect_equivalent(
+        sum(x$probability.tables[[i]] != x$probability.tables[[i-1]]) > 0,
+        TRUE
+      )
+    }
+  }
+  
 })
 
 
